@@ -85,7 +85,7 @@ test_that("use_cassette fails well", {
   # persist_with valid value
   expect_error(
     suppressMessages(use_cassette("newbar6", {}, serialize_with = "howdy")),
-    "The requested VCR cassette serializer \\(howdy\\) is not registered"
+    "The requested vcr cassette serializer \\(howdy\\) is not registered"
   )
 })
 
